"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const xstate_1 = require("xstate");
const interpreter_1 = require("xstate/lib/interpreter");
function useMachine(config, options, initialContext) {
    const machine = react_1.useMemo(() => xstate_1.Machine(config, options, initialContext));
    const [state, setState] = react_1.useState(machine.initialState);
    const [exState, setExState] = react_1.useState(machine.context);
    const [send, setSend] = react_1.useState();
    react_1.useEffect(() => {
        const interpreter = interpreter_1.interpret(machine);
        interpreter.init();
        interpreter.onTransition(setState);
        interpreter.onChange(setExState);
        setSend(() => interpreter.send);
        return () => {
            interpreter.off(setState);
            interpreter.off(setExState);
        };
    }, []);
    return { state, send, exState };
}
exports.useMachine = useMachine;
